Parameters — Siren - Interactive Redescription Mining - User Guide

### Navigation

- previous
- Siren - Interactive Redescription Mining - User Guide »

# Parameters

Note

Siren allows to tune various parameters via an interface menu Edit ‣ Preferences.

An XML preferences file stores all non-default parameters.

The parameters that can be set through the preference interface can be mainly divided into two categories, mining parameters, that pertain to the mining algorithm, and visualization parameters, that pertain to the interactive visualizations, each split over several tabs.

## Mining parameters

Mining parameters are specified here and can be set through the interface.

Quite many parameters are available for tuning, but in general only a few of them need to be adjusted. In particular, the parameters setting threshold values on the support of the queries, on the accuracy of the returned redescriptions, as well as on the type of queries, are the most important ones.

## Visualization parameters

Visualization parameters are specified here and can be set through the interface. For instance, they allows to modify the appearance of the maps, choose the colors of the different support subsets, etc.

## Other parameters

It is possible to adjust the parameters through the interface then export them to a file. In particular, a template can be generated and exported which can be used to run the ReReMi mining algorithm from the command line, after filling in input/output parameters, which are specified here.

Interface parameters, such as the splits and external server parameters, set through dedicated menu in the interface are specified here .

### Navigation

- previous
- Siren - Interactive Redescription Mining - User Guide »